@@ -7,7 +7,7 @@ use Carp qw( croak );
 use FFI::Platypus::Function;
 
 # ABSTRACT: Write Perl bindings to non-Perl libraries with FFI. No XS required.
-our $VERSION = '0.76_02'; # TRIAL VERSION
+our $VERSION = '0.77_01'; # TRIAL VERSION
 
 # Platypus Man,
 # Platypus Man,
@@ -550,7 +550,7 @@ package FFI::Platypus::Type;
 
 use Carp qw( croak );
 
-our $VERSION = '0.76_02'; # TRIAL VERSION
+our $VERSION = '0.77_01'; # TRIAL VERSION
 
 sub new
 {
@@ -652,7 +652,7 @@ FFI::Platypus - Write Perl bindings to non-Perl libraries with FFI. No XS requir
 
 =head1 VERSION
 
-version 0.76_02
+version 0.77_01
 
 =head1 SYNOPSIS
 
@@ -1990,7 +1990,7 @@ libtest> command to build it.  Example:
 
  % perl Makefile.PL
  % make
- % make mymm_test
+ % make mymm-test
  % prove -bv t
  # or an individual test
  % perl -Mblib t/ffi_platypus_memory.t
@@ -2032,6 +2032,15 @@ environment variable when you run C<Makefile.PL>:
  Writing Makefile for FFI::Platypus
  Writing MYMETA.yml and MYMETA.json
 
+=item V
+
+When building platypus may hide some of the excessive output when
+probing and building, unless you set C<V> to a true value.
+
+ % env V=1 perl Makefile.PL
+ % make V=1
+ ...
+
 =back
 
 =head2 Coding Guidelines
