@@ -11,7 +11,7 @@ use Capture::Tiny qw( capture_merged capture );
 use File::Temp qw( tempdir );
 
 # ABSTRACT: System detection and probing for FFI extensions.
-our $VERSION = '0.76_02'; # TRIAL VERSION
+our $VERSION = '0.77_01'; # TRIAL VERSION
 
 
 sub new
@@ -51,7 +51,7 @@ sub new
     data          => $data,
     dir           => tempdir( CLEANUP => 1, TEMPLATE => 'ffi-probe-XXXXXX', DIR => '.' ),
     counter       => 0,
-    runner        => $args{runner} || FFI::Probe::Runner->new,
+    runner        => $args{runner},
     alien         => $args{alien} || [],
     cflags        => $args{cflags},
     libs          => $args{libs},
@@ -60,6 +60,12 @@ sub new
   $self;
 }
 
+sub _runner
+{
+  my($self) = @_;
+  $self->{runner} ||= FFI::Probe::Runner->new;
+}
+
 
 sub check_header
 {
@@ -201,7 +207,7 @@ sub check_eval
     $lib;
   };
 
-  my $result = $self->{runner}->run($lib->path);
+  my $result = $self->_runner->run($lib->path);
 
   $self->log("[stdout]");
   $self->log($result->stdout);
@@ -354,9 +360,18 @@ sub set
   my $value = pop;
   my @key = @_;
 
+  my $print_value = $value;
+  if(ref $print_value)
+  {
+    my $d = Data::Dumper->new([$value], [qw($value)]);
+    $d->Indent(0);
+    $d->Terse(1);
+    $print_value = $d->Dump;
+  }
+
   my $key = join ".", map { /\./ ? "\"$_\"" : $_ } @key;
-  print "$key=$value\n";
-  $self->log("$key=$value");
+  print "PR $key=$print_value\n";
+  $self->log("$key=$print_value");
   _set($self->{data}, $value, @key);
 }
 
@@ -440,7 +455,7 @@ FFI::Probe - System detection and probing for FFI extensions.
 
 =head1 VERSION
 
-version 0.76_02
+version 0.77_01
 
 =head1 SYNOPSIS
 
